#!/bin/bash

#
# Prepares the Javascript files in a directory for deployment to
# a web server via the following steps:
#
# 1) Creates DEPLOYDIR if it does not exist and removes any
#    existing contents.
# 2) Copies master.js to DEPLOYDIR.
# 3) Iterates through js files in directory.  Files in the
#    if clause below are skipped (page_init.js is an embedded
#    script that should not be deployed OTA, master.js is
#    copied separately and should not be fingerprinted.
# 4) For all remaining js files, generate a checksum on the file
#    and copy it to DEPLOYDIR with a new name that includes
#    the checksum:
#
#       ted.js => ./deploy/ted_cksum_2275856446.js
# 5) Updates DEPLOYDIR/master.js to convert script name
#    references to point to the new name that includes
#    the checksum fingerprint.
#
# Tested on cygwin using Windows 7.  Should work on Linux or any
# other OS that supports bash and Unix tools.
#
# NOTE: Be consistent about running this on the same machine type
# before each deploy.  If you run on a machine with a different
# cksum implementation compared to the one used for the previous
# deploy, all of the fingerprints will change, and users will
# end up unnecessarily hitting the web server for new copies of
# script files that haven't actually changed.

# Prepare deployment directory.  Should be different from the
# directory where this script and the Javascript files reside.
DEPLOYDIR="./deploy"
test -d "$DEPLOYDIR" || mkdir -p "$DEPLOYDIR"
rm -f ${DEPLOYDIR}/*
cp master.js ${DEPLOYDIR}
# Rules from .htaccess should now be part of the web server config,
# so .htaccess only needed for temporary overrides
# cp ".htaccess" ${DEPLOYDIR}

# Process files
for f in *.js
do
    if [ "$f" == "page_init.js" -o "$f" == "master.js" ]; then
        # Skip files we don't want to fingerprint
        echo "Skipping $f"
    else
        # Copy to fingerprinted name
        CKSUM=`cksum $f | cut -f 1 -d " "`
        FNAME=`echo $f | cut -f 1 -d "."`
        NEWNAME="${FNAME}_cksum_${CKSUM}.js"
        echo "Copying $f to ${DEPLOYDIR}/${NEWNAME}"
        cp "$f" "${DEPLOYDIR}/${NEWNAME}"
        # Update references to name in master.js
        sed -i "s/${f}/${NEWNAME}/g" ${DEPLOYDIR}/master.js

    fi
done
